@@ -31,6 +31,7 @@ use NewsExtractor::SiteSpecificExtractor::www_thestandnews_com;
 use NewsExtractor::SiteSpecificExtractor::www_hkcnews_com;
 use NewsExtractor::SiteSpecificExtractor::www_epochtimes_com;
 use NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw;
+use NewsExtractor::SiteSpecificExtractor::www_idn_com_tw;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -80,6 +81,7 @@ use constant {
         'news.ebc.net.tw' => 'NewsExtractor::SiteSpecificExtractor::news_ebc_net_tw',
         'newnet.tw' => 'NewsExtractor::SiteSpecificExtractor::newnet_tw',
         'www.ttv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ttv_com_tw',
+        'www.idn.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_idn_com_tw',
     },
     CSSRuleSetByHost => {
         'www.taiwannews.com.tw' => {
@@ -89,10 +91,10 @@ use constant {
             content_text => 'article.article',
         },
         'udn.com' => {
-            headline   => '#story_art_title',
-            dateline   => '.story_bady_info_author > span:nth-child(1)',
-            journalist => '.story_bady_info_author > a:nth-child(2)',
-            content_text => 'div#article_body',
+            headline   => 'h1.article-content__title',
+            dateline   => '.authors time.article-content__time',
+            journalist => '.authors span.article-content__author',
+            content_text => 'div.article-content__paragraph section.article-content__editor',
         },
         'www.nownews.com' => {
             headline   => 'h1.entry-title',
